@echo off

setlocal enabledelayedexpansion

rem You must first customize variables SAWPath, SACPath, and VSTSrcPaths
rem 	in the SAWSACVSTINIToolConfig.bat file!!!

rem -Name		: SAWSACVSTINITool.bat
rem -Version		: 1.0
rem -Date		: 11/02/09
rem -Author 		: Rich McCoy
rem -Website		: http://www.richmccoy.com
rem -Purpose		: To create ini files for SAWStudio & SAC for VST's/VSTi's residing outside
rem				the RML install folder structure.
rem -Thanks		: To J. Talbert (http://www.efofex.net/software.html) for the original SAW
rem				VST Ini Tool. I used it many times, but it doesn't seem to work 
rem				with Windows 7 or SAC.
rem -Reason Why #1	: I could not get the very handy SAW VSTI Ini Tool to work with Windows 7
rem				due to a .NET Framework version mismatch (thus as painful as this
rem				was to do as a batch file, this tool is written with no .NET, Java, 
rem				or whatever system requirements. It should work on W2K, XP, W2K3, 
rem				Vista, W2K8, and W7, although I have not tested it on each platform.)
rem -Reason Why #2	: The *SAW* VST Ini Tool was written before SAC existed, and therefore is 
rem				not "SAC Aware", so it doesn't update ini files for SAC.
rem -Use		: Use at your own risk. I wrote this for myself, but am sharing it with you.
rem				This program is provided as is, with no warranties or guarantees.
rem				PLEASE BACKUP YOUR VST_PlugIns FOLDERS for SAWStudio & SAC first!!!!
rem -Usage		: 1. Edit the accompanying SAWSACVSTINIToolConfig.bat, modifying variables 
rem				SAWPath, SACPath, and VSTPaths (Take care you are not modifying the
rem				"Example" lines. It's easy to do, and while it won't have any effect,
rem				you won't be scanning the correct folders... because it doesn't have
rem				any effect.
rem			: 2. Save it.
rem			: 3. Launch this file by clicking on this file, or by opening a command prompt
rem				window, going to the folder where this lives, and typing 
rem				SAWSACVSTINITool.bat. ***
rem			  4, Answer the onscreen questions.
rem
rem			  *** NOTE: It's probably necessary to run this with "Run As Administrator"
rem				under Vista and newer OS's. Right click this bat file and choose that 
rem				option, or open the Command Prompt window the same way and then type
rem				in SAWSACVSTINITool.bat. This will not run correctly without elevated
rem				privileges received from running in that mode.

rem Deal with UAC/Run As Administrator changing our path!!!
pushd "%cd%"
cd /d "%~dp0"

rem Save where we start.
set startuppath=%cd%

rem Files we will read from and write to...
set configbatfile="%cd%\SAWSACVSTINIToolConfig.bat"
set logfile="%cd%\SAWSACVSTINITool.log"

cls

echo - New logfile created > %logfile%
echo - startuppath = %startuppath% >> %logfile%

rem Check for NT-based Windows OS (WinNT, W2K, XP, W2K3, Vista, W2K8, W7, etc.)
if not %OS%==Windows_NT (
	echo This program will not run on this operating system!
	echo - This program will not run on this OS: %OS% >> %logfile%
	goto STOP
)

echo - OS returned as %OS% - OK >> %logfile%

rem Set variables stored in configbatfile.

echo - Setting variables from %configbatfile% >> %logfile%

if not exist %configbatfile% (
	echo Config Bat File %configbatfile% not found in folder %cd% 
	echo - Config Bat File %configbatfile% not found in folder %cd% >> %logfile%
	goto STOP
)

rem Execute the config batch file to set the site specific variables.
call %configbatfile%

if defined SAWPath (
	echo - SAWPath = %SAWPath% >> %logfile%
) else (
	echo - SAWPath is not defined >> %logfile%
	)
if defined SACPath (
	echo - SACPath = %SACPath% >> %logfile%
) else (
	echo - SACPath is not defined >> %logfile%
	)
if defined VSTSrcPaths (
	echo - VSTSrcPaths = %VSTSrcPaths% >> %logfile%
) else (
	echo - VSTSrcPaths is not defined >> %logfile%
	)
if defined skipinstructions (echo - skipinstructions = %skipinstructions% >> %logfile%)

if %skipinstructions%==Y goto CONTINUE2
if %skipinstructions%==y goto CONTINUE2

echo This program will build the ini files for SAWStudio and/or SAC to use VST's and
echo VSTi's installed in folders outside of the RML Labs install folder structures.
echo.
echo By running this program, you agree to do so at your own risk. It comes with no
echo warranties or guarantees.
echo.
echo Please backup your SAWStudio and SAC folders, or anything else you might need
echo before continuing.
echo.
echo Actions taken by this program are logged to:
echo %logfile%.
echo.
echo Note: You must have administrator rights on this system! For Vista and later,
echo you must go a step further and run this program with "Run as Administrator".
echo.

:QUESTION1
echo - Asking QUESTION1 >> %logfile%

set continue=?
set /p continue=Do you want to continue? (y/n)

echo - continue = %continue% >> %logfile%

if %continue%==Y goto CONTINUE1
if %continue%==y goto CONTINUE1
if %continue%==N goto STOP
if %continue%==n goto STOP
goto QUESTION1

:CONTINUE1
echo - In CONTINUE1 >> %logfile%

cls
echo This program uses info in the file %configbatfile% in the 
echo %cd% folder to know where SAWStudio and SAC are installed...
echo as well as where to look for installed VST's/VSTi's.
echo.
echo If you have not already done so, edit %configbatfile% 
echo in Notepad (or some other text editor) and customize the SAWPath and SACPath 
echo variables to point to the main folders where SAWStudio and SAC are respectively
echo installed. If you do not have SAWStudio or SAC, you do not have to edit its 
echo related variable, but you can also remove the related line or section in  
echo %configbatfile% to not be asked about the 
echo respective product by this file.
echo.
echo You must also customize the VSTSrcPaths variables in 
echo %configbatfile% to point to the different paths where
echo you have VST's and VSTi's installed.
echo.
echo So, you will need to set the SAWPath, SACPath, and VSTSrcPaths variables in 
echo the %configbatfile% in %cd%!
echo.

:QUESTION2
echo - Asking QUESTION2 >> %logfile%

set continue=?
set /p continue=Have you already made these changes? (y/n)

echo - continue = %continue% >> %logfile%

if %continue%==Y goto CONTINUE2
if %continue%==y goto CONTINUE2
if %continue%==N goto STOP
if %continue%==n goto STOP
goto QUESTION2

:CONTINUE2
echo - In CONTINUE2 >> %logfile%

cls

if not defined VSTSrcPaths (
	echo VSTSrcPaths variable in %configbatfile% is not defined!
	echo - VSTSrcPaths variable in %configbatfile% is not defined! >> %logfile%
	goto STOP
)

set RMLVSTRelativePath=\VST_Plugins
set deleteSACINIFiles=?
set deleteSAWINIFiles=?

for %%a in (%SAWPath%) do set SAWPath=%%~dpfa
for %%a in (%SACPath%) do set SACPath=%%~dpfa

if defined SAWPath set SAWVSTPath=%SAWPath%%RMLVSTRelativePath%
if defined SAWPath echo - SAWVSTPath is %SAWVSTPath% >> %logfile%

if defined SACPath set SACVSTPath=%SACPath%%RMLVSTRelativePath%
if defined SACPath echo - SACVSTPath is %SACVSTPath% >> %logfile%

echo VSTSrcPaths = %VSTSrcPaths%
echo.
echo so VST Source Paths to be scanned =
echo - Enumerated VST Source Paths: >> %logfile%
for %%a in (%VSTSrcPaths%) do (
	echo -- %%~dpfa
	echo    %%~dpfa >> %logfile%
	if not exist %%a (
		echo    *** The above folder does not exist! ***
		echo    *** The above folder does not exist! *** >> %logfile%
	)
)
echo.
if defined SAWPath echo -- %SAWPath%

:QUESTION3
echo - In QUESTION3 >> %logfile%

set SAWStudioInstalled=?
if not defined SAWPath goto QUESTION4
set /p SAWStudioInstalled=Is SAWStudio installed in the above folder? (y/n/q)

echo - SAWStudioInstalled = %SAWStudioInstalled% >> %logfile%

if %SAWStudioInstalled%==Y goto CONTINUE4
if %SAWStudioInstalled%==y goto CONTINUE4
if %SAWStudioInstalled%==N goto QUESTION4
if %SAWStudioInstalled%==n goto QUESTION4
if %SAWStudioInstalled%==Q goto STOP
if %SAWStudioInstalled%==q goto STOP
goto QUESTION3

:CONTINUE4
echo - In CONTINUE4 >> %logfile%

set SAWStudioInstalled=Y
if not exist "%SAWVSTPath%" (
	echo.
	echo Expected SAWStudio VST_PlugIns Path
	echo %SAWVSTPath% does not exist!
	echo - Expected SAWStudio VST_PlugIns Path %SAWVSTPath% does not exist! >> %logfile%
	goto STOP
)

:QUESTION4
echo - In QUESTION4 >> %logfile%

echo.
if defined SACPath echo -- %SACPath%

:QUESTION4a
echo - In QUESTION4a >> %logfile%

set SACInstalled=?
if not defined SACPath goto QUESTION5

set /p SACInstalled=Is SAC installed in the above folder? (y/n/q)

echo - SACInstalled = %SACInstalled% >> %logfile%

if %SACInstalled%==Y goto CONTINUE5
if %SACInstalled%==y goto CONTINUE5
if %SACInstalled%==N goto QUESTION5
if %SACInstalled%==n goto QUESTION5
if %SACInstalled%==Q goto STOP
if %SACInstalled%==q goto STOP
goto QUESTION4a

:CONTINUE5
echo - In CONTINUE5 >> %logfile%

set SACInstalled=Y

if not exist "%SACVSTPath%" (
	echo.
	echo Expected SAC VST_Plugins Path
	echo %SACVSTPath% does not exist!
	echo - Expected SAC VST_PlugIns Path %SACVSTPath% does not exist! >> %logfile%
	goto STOP
)


:QUESTION5
echo - In QUESTION5 >> %logfile%

if not %SAWStudioInstalled%==Y if not %SACInstalled%==Y (
	echo Nothing to do - You don't want to update either product...
	echo - Nothing to do - User doesn't want to update either product >> %logfile%
	goto STOP
)

if not %SAWStudioInstalled%==Y goto QUESTION6

echo.
echo -- %SAWVSTPath%

:QUESTION5a
echo - In QUESTION5a >> %logfile%

set /p deleteSAWINIFiles=Delete existing VST/VSTi SAWStudio ini files here before refreshing? (y/n/q)

echo - deleteSAWINIFiles = %deleteSAWINIFiles% >> %logfile%

if %deleteSAWINIFiles%==Y goto CONTINUE6
if %deleteSAWINIFiles%==y goto CONTINUE6
if %deleteSAWINIFiles%==N goto QUESTION6
if %deleteSAWINIFiles%==n goto QUESTION6
if %deleteSAWINIFiles%==Q goto STOP
if %deleteSAWINIFiles%==q goto STOP
goto QUESTION5a

:CONTINUE6
echo - In CONTINUE6 >> %logfile%

set deleteSAWINIFiles=Y

:QUESTION6
echo - In QUESTION6 >> %logfile%

if not %SACInstalled%==Y goto QUESTION7

echo.
echo -- %SACVSTPath%

:QUESTION6a
echo - In QUESTION6a >> %logfile%

set /p deleteSACINIFiles=Delete existing VST/VSTi SAC ini files here before refreshing? (y/n/q)

echo - deleteSACINIFiles = %deleteSACINIFiles% >> %logfile%

if %deleteSACINIFiles%==Y goto CONTINUE7
if %deleteSACINIFiles%==y goto CONTINUE7
if %deleteSACINIFiles%==N goto QUESTION7
if %deleteSACINIFiles%==n goto QUESTION7
if %deleteSACINIFiles%==Q goto STOP
if %deleteSACINIFiles%==q goto STOP
goto QUESTION6a

:CONTINUE7
echo - In CONTINUE7 >> %logfile%

set deleteSACINIFiles=Y

:QUESTION7
echo - In QUESTION7 >> %logfile%
echo.

:QUESTION7a
echo - In QUESTION7a >> %logfile%

set viewFolders=?
set /p viewfolders=View folders in Windows Explorer after refresh? (y/n/q)

echo - viewfolders = %viewfolders% >> %logfile%

if %viewfolders%==Y goto CONTINUE8
if %viewfolders%==y goto CONTINUE8
if %viewfolders%==N goto QUESTION8
if %viewfolders%==n goto QUESTION8
if %viewfolders%==Q goto STOP
if %viewfolders%==q goto STOP
goto QUESTION7a

:CONTINUE8
echo - In CONTINUE8 >> %logfile%

set viewfolders=Y

:QUESTION8
echo - In QUESTION8 >> %logfile%

echo.

:QUESTION8a
echo - In QUESTION8a >> %logfile%

set continue=?
set /p continue=Rebuild ini files based on dialog above? (y/n)

echo - Rebuild ini files (continue) = %continue% >> %logfile%

if %continue%==Y goto CONTINUE9
if %continue%==y goto CONTINUE9
if %continue%==N goto STOP
if %continue%==n goto STOP
goto QUESTION8a

:CONTINUE9
echo - In CONTINUE9 >> %logfile%

if not %deleteSAWINIFiles%==Y goto CONTINUE10

rem This is where we cleanup the SAWStudio ini files...
echo Deleting all ini files in %SAWVSTPath%
echo - Deleting all ini files in %SAWVSTPath% >> %logfile%
del "%SAWVSTPath%\*.ini" /q

:CONTINUE10
echo - In CONTINUE10 >> %logfile%

if not %deleteSACINIFiles%==Y goto CONTINUE11

rem This is where we create the SAC ini files.
echo Deleting all ini files in %SACVSTPath%
echo - Deleting all ini files in %SACVSTPath% >> %logfile%
del "%SACVSTPath%\*.ini" /q

:CONTINUE11
echo - In CONTINUE11 >> %logfile%

rem These two "for" loops are where we create the new ini files.

echo - Ready to create ini files >> %logfile%

for %%v in (%VSTSrcPaths%) do (
	if exist %%v (
		cd /d "%%~v%"
		for /r %%y in (*.dll) do (
			if %SAWStudioInstalled%==Y (
				echo %%y > "%SAWVSTPath%\%%~ny.ini"
				echo Created %%~ny.ini in %SAWVSTPath%
				echo     Created %%~ny.ini in %SAWVSTPath% for %%y >> %logfile%
			)
			if %SACInstalled%==Y (
				echo %%y > "%SACVSTPath%\%%~ny.ini"
				echo Created %%~ny.ini in %SACVSTPath%
				echo     Created %%~ny.ini in %SACVSTPath% for %%y >> %logfile%
			)
		cd /d %startuppath%
		)
	) else (
		echo.
		echo Warning: VST Source Folder %%v does not exist!
		echo Ini files cannot be created for this folder.
		echo.
		echo     Warning: VST Source Folder %%v does not exist! Ini files cannot be created from this folder >> %logfile%
		pause
	)
)

echo - Finished creating ini files >> %logfile%

rem Show them the folders if they wanted that.
if %viewfolders%==Y if %SAWStudioInstalled%==Y (
	start explorer.exe /e,"%SAWVSTPath%"
	echo - Launched explorer.exe for %SAWVSTPath% >> %logfile%
)

if %viewfolders%==Y if %SACInstalled%==Y (
	start explorer.exe /e,"%SACVSTPath%"
	echo - Launched explorer.exe for %SACVSTPath% >> %logfile%
)

goto DONE

:STOP
echo Processing stopped!
echo - Processing stopped! >> %logfile%
goto END

:DONE
echo.
echo Done!
echo - Done! >> %logfile%

:END
endlocal
pause
